/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import { CfnTable, CfnTableProps } from "aws-cdk-lib/aws-glue";
import { Construct } from "constructs";
import * as glue from 'aws-cdk-lib/aws-glue';
import * as s3assets from 'aws-cdk-lib/aws-s3-assets';
/**
 * @internal This is an internal core function and should not be called directly by Solutions Constructs clients.
 *
 * Method to build the default table props
 *
 * @param scope
 * @param database
 * @param fieldSchema
 * @param sourceType
 * @param parameters - Key value pairs of parameters. If source type is 'Kinesis', pass Kinesis Data Stream name with key
 *  as 'STREAM_NAME'. Example: {STREAM_NAME: 'KinesisStreamConstruct.streamName'}
 */
export declare function DefaultGlueTable(scope: Construct, tableProps: CfnTableProps): CfnTable;
export interface GlueProps {
    readonly existingGlueJob?: glue.CfnJob;
    readonly etlCodeAsset?: s3assets.Asset;
    readonly glueJobProps?: glue.CfnJobProps | any;
    readonly fieldSchema?: glue.CfnTable.ColumnProperty[];
    readonly existingTable?: glue.CfnTable;
    readonly tablePropss?: glue.CfnTableProps;
}
export declare function CheckGlueProps(propsObject: GlueProps | any): void;
